Model Code:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson2/src/server.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson2/src/client.py
   :language: python
   :linenos:


(`Example in other languages <examples/rpc_lesson2.html>`__)
